@@ -2,7 +2,7 @@ package App::optex;
 use strict;
 use warnings;
 
-our $VERSION = "v0.99.2";
+our $VERSION = "v0.1";
 
 1;
 
@@ -12,7 +12,7 @@ __END__
 
 =head1 NAME
 
-optex - optex command module directory
+optex - optex command module direcrtory
 
 =head1 SYNOPSIS
 
@@ -22,8 +22,7 @@ or make symbolic link to B<optex> in the name of target command.
 
 =head1 DESCRIPTION
 
-This directory contains modules for B<optex> command.  Manual for
-B<optex> command is included in the script itself.
+This directory contains modules for B<optex> command.
 
 =head1 SEE ALSO
 
@@ -33,13 +32,13 @@ L<Getopt::EX>
 
 =head1 LICENSE
 
-Copyright 2017- Kazumasa Utashiro.
+Copyright (C) Kazumasa Utashiro.
 
 You can redistribute it and/or modify it under the same terms
 as Perl itself.
 
 =head1 AUTHOR
 
-Kazumasa Utashiro
+Kazumasa Utashiro E<lt>kaz@utashiro.comE<gt>
 
 =cut
